@@ -7,12 +7,20 @@ from bisect import bisect_left, bisect_right
 from collections import defaultdict
 
 import numpy as np
+from natsort import natsorted
 import torch
+import pandas as pd
 
 
 ################################################################################
 ## strings
 ################################################################################
+def decapitalize(s):
+    if not s:  # check that s is not empty string
+        return s
+    return s[0].lower() + s[1:]
+
+
 def connect_strs(strs, filler="_"):  # connect_nums also works as connect_strs
     """
     Example:
@@ -55,6 +63,39 @@ def squeeze_spaces(string, pattern=" +", repl=" "):
     return re.sub(pattern, repl, string)
 
 
+def search(patterns, strings):
+    """
+    Example:
+        patterns = ['orange', 'banana']
+        strings = ['apple', 'orange', 'apple', 'apple_juice', 'banana', 'orange_juice']
+        print(search(patterns, strings))
+        # ([1, 4, 5], ['orange', 'banana', 'orange_juice'])
+
+        patterns = 'orange'
+        strings = ['apple', 'orange', 'apple', 'apple_juice', 'banana', 'orange_juice']
+        print(search(patterns, strings))
+        # ([1, 5], ['orange', 'orange_juice'])
+    """
+    ## For single string objects
+    if not isinstance(strings, (list, tuple, pd.core.indexes.base.Index)):
+        strings = [strings]
+    if not isinstance(patterns, (list, tuple, pd.core.indexes.base.Index)):
+        patterns = [patterns]
+
+    ## Main
+    indi_matched = []
+    for pattern in patterns:
+        for i_str, string in enumerate(strings):
+            m = re.search(pattern, string)
+            if m is not None:
+                indi_matched.append(i_str)
+
+    ## Sorts the indices according to the original strings
+    indi_matched = natsorted(indi_matched)
+    keys_matched = list(np.array(strings)[indi_matched])
+    return indi_matched, keys_matched
+
+
 def grep(str_list, search_key):
     """
     Example:
